# ACP Remote API

This page documents the public surface re-exported by `acpremote`.

## Core Functions

::: acpremote.connect_acp

::: acpremote.connect_remote_agent

::: acpremote.serve_acp

::: acpremote.serve_command

::: acpremote.serve_stdio_command

::: acpremote.serve_remote_agent

## Transport Configuration

::: acpremote.TransportOptions

::: acpremote.ServerOptions

::: acpremote.ServerPaths

::: acpremote.CommandOptions

::: acpremote.TransportMetadata

::: acpremote.ServerMetadata

## Runtime Classes

::: acpremote.RemoteProxyAgent

::: acpremote.RemoteClientConnection

::: acpremote.WebSocketStreamBridge

## Helper Functions

::: acpremote.build_server_paths

::: acpremote.build_server_metadata

::: acpremote.normalize_mount_path
